const schema = [
  {
    prop: "name",
    label: "名称",
    type: "input",
    props: {
      placeholder: "请填写名称",
      showWordLimit: true,
      maxlength: 20
    },
    rules: [
      {
        required: true,
        message: "请填写名称"
      }
    ]
  },
  {
    prop: "key",
    label: "key",
    type: "input",
    props: {
      placeholder: "请填写组名",
      showWordLimit: true,
      maxlength: 100
    },
    rules: [
      {
        required: true,
        message: "请填写组名"
      },
      {
        pattern: /^([a-z0-9]+)(\.([a-z0-9]+))+$/,
        message: "组名格式为xxx.xxx.xxx，至少一个点分隔，由小写字母、数字组成"
      }
    ]
  },
  {
    prop: "nameEn",
    label: "英文名称",
    type: "input",
    props: {
      placeholder: "请填写英文名称",
      showWordLimit: true,
      maxlength: 20
    },
    rules: [
      {
        required: true,
        message: "请填写英文名称"
      }
    ]
  },
  {
    prop: "tag",
    label: "标签",
    type: "input",
    props: {
      placeholder: "请填写标签名称",
      showWordLimit: true,
      maxlength: 10
    },
    rules: [
      {
        required: true,
        message: "请填写标签名称"
      }
    ]
  }
];

export default {
  "config.title": "组件分类",
  "config.toolbar.edit.disabled": ({ component }) => {
    return !component("list1").action("getActive");
  },
  "config.toolbar.delete.disabled": ({ component }) => {
    return !component("list1").action("getActive");
  },
  "events.init": async ({ dispatch }) => {
    await dispatch("queryComponentGroup");
  },
  "events.change": async ({ dispatch }) => {
    await dispatch("queryComponent");
  },
  "events.toolbarClick/create": async ({ dispatch, modal }) => {
    modal({
      data: {},
      title: "新建组件组",
      schema,
      onConfirm: async ({ data, close }) => {
        await dispatch("createComponentGroup", data);
        await dispatch("queryComponentGroup");
        close();
      }
    });
  },
  "events.toolbarClick/edit": async ({ dispatch, component, modal }) => {
    const active = component("list1").action("getActive");
    modal({
      data: active,
      title: "编辑组件组",
      schema,
      onConfirm: async ({ data, close }) => {
        await dispatch("editComponentGroup", data);
        await dispatch("queryComponentGroup");
        close();
      }
    });
  },
  "events.toolbarClick/delete": async ({ dispatch, component, confirm }) => {
    const active = component("list1").action("getActive");
    confirm({
      title: "是否删除",
      content: "即将删除所选数据，是否继续",
      confirmButtonText: "删除",
      cancelButtonText: "关闭",
      closeOnClickModal: false,
      onConfirm: async () => {
        await dispatch("deleteComponentGroup", {
          ids: active.id
        });
        await dispatch("queryComponentGroup");
      }
    });
  }
};
